package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.MinioFileMapper;
import com.ruoyi.system.domain.MinioFile;
import com.ruoyi.system.service.IMinioFileService;

/**
 * minio文件存储Service业务层处理
 *
 * @author ruoyi
 * @date 2024-07-30
 */
@Service
public class MinioFileServiceImpl implements IMinioFileService
{
    @Autowired
    private MinioFileMapper minioFileMapper;

    /**
     * 查询minio文件存储
     *
     * @param id minio文件存储主键
     * @return minio文件存储
     */
    @Override
    public MinioFile selectMinioFileById(Long id)
    {
        return minioFileMapper.selectMinioFileById(id);
    }

    /**
     * 查询minio文件存储列表
     *
     * @param minioFile minio文件存储
     * @return minio文件存储
     */
    @Override
    public List<MinioFile> selectMinioFileList(MinioFile minioFile)
    {
        return minioFileMapper.selectMinioFileList(minioFile);
    }

    /**
     * 新增minio文件存储
     *
     * @param minioFile minio文件存储
     * @return 结果
     */
    @Override
    public int insertMinioFile(MinioFile minioFile)
    {
        return minioFileMapper.insertMinioFile(minioFile);
    }

    /**
     * 修改minio文件存储
     *
     * @param minioFile minio文件存储
     * @return 结果
     */
    @Override
    public int updateMinioFile(MinioFile minioFile)
    {
        return minioFileMapper.updateMinioFile(minioFile);
    }

    /**
     * 批量删除minio文件存储
     *
     * @param ids 需要删除的minio文件存储主键
     * @return 结果
     */
    @Override
    public int deleteMinioFileByIds(Long[] ids)
    {
        return minioFileMapper.deleteMinioFileByIds(ids);
    }

    @Override
    public MinioFile selectMinioFileName(String fileName) {
        return minioFileMapper.selectMinioFileName(fileName);
    }

    /**
     * 删除minio文件存储信息
     *
     * @param id minio文件存储主键
     * @return 结果
     */
    @Override
    public int deleteMinioFileById(Long id)
    {
        return minioFileMapper.deleteMinioFileById(id);
    }
}
